@@ -337,10 +337,7 @@ class LoadMaster(HttpClient):
 class KempBaseObjectModel(object):
     # blacklist attributes that shouldn't be pushed to the loadmaster.
     _API_IGNORE = (
-        "ip_address",
-        "endpoint",
-        "rsindex",
-        "vsindex",
+        "ip_address", "endpoint", "rsindex", "vsindex", "index", "status",
     )
 
     def __repr__(self):
